@@ -5,6 +5,7 @@ from utils import UrllibWrapper
 import dbus, time
 import string
 import urllib
+import shutil
 
 try:
     import libxml2
@@ -126,7 +127,7 @@ class MussorgskyAlbumArt:
         for image_url in self.__get_url_from_google_results_page (results_page):
             if (not image_url):
                 # Some searches doesn't return anything at all!
-                print "No images result returned"
+                print "No image results returned"
                 break
 
             if (counter >= max_alternatives):
@@ -146,15 +147,24 @@ class MussorgskyAlbumArt:
             
 
     def save_alternative (self, artist, album, img_path, thumb_path):
-        if not os.path.exists (img_path) or not os.path.exists (thumb_path):
-            print "**** CRITICAL **** image in path", path, "doesn't exist!"
+        if not os.path.exists (img_path):
+            print "**** CRITICAL **** image in path", img_path, "doesn't exist!"
             return (None, None)
+
+        if not os.path.exists (thumb_path):
+            print "**** CRITICAL **** image in path", thumb_path, "doesn't exist!"
+            return (None, None)
+
         
         filename = getCoverArtFileName (album)
         thumbnail = getCoverArtThumbFileName (album)
 
-        os.rename (img_path, filename)
-        os.rename (thumb_path, thumbnail)
+        print "Debug: img_path:", img_path, "filename:", filename
+        print "Debug: thumb_path:", thumb_path, "thumbnail:", thumbnail
+
+        shutil.move (img_path, filename)
+        shutil.move (thumb_path, thumbnail)
+
 
         return (filename, thumbnail)
 
