@@ -6,10 +6,16 @@ from album_art_panel import MussorgskyAlbumArtPanel
 from browse_panel import MussorgskyBrowsePanel
 from fancy_button import FancyButton, settings_changed
 
+import i18n
+_ = i18n.language.gettext
+
 class MussorgskyMainWindow (hildon.StackableWindow):
 
     def __init__ (self):
         hildon.StackableWindow.__init__ (self)
+
+
+        
         self.tracker = TrackerBackend ()
         self.set_title ("MussOrgsky")
         self.set_border_width (12)
@@ -48,13 +54,13 @@ class MussorgskyMainWindow (hildon.StackableWindow):
         hbox = gtk.HBox ()
 
         align1 = gtk.Alignment (xalign=0.5, yalign=0.5)
-        button1 = FancyButton (image1, "Browse metadata")
+        button1 = FancyButton (image1, _("Metadata"))
         button1.connect ("clicked", self.browse_clicked)
         align1.add (button1)
         hbox.pack_start (align1)
 
         align2 = gtk.Alignment (xalign=0.5, yalign=0.5)
-        button2 = FancyButton(image2, "Album art")
+        button2 = FancyButton(image2, _("Album art"))
         button2.connect ("clicked", self.album_art_clicked)
         align2.add (button2)
         hbox.pack_start (align2)
@@ -64,6 +70,7 @@ class MussorgskyMainWindow (hildon.StackableWindow):
 
 if __name__ == "__main__":
 
+
     try:
         window = MussorgskyMainWindow ()
         
